@@ -5,6 +5,13 @@ from tempfile import gettempdir, mkdtemp
 from types import SimpleNamespace
 from typing import List
 
+import yt_dlp
+
+
+def now():
+    return int(datetime.now().timestamp())
+
+
 FAKE_SUBTITLE = os.path.join(gettempdir(), "sub.srt")  # https://github.com/skorokithakis/catt/issues/393
 CAST_NOW_PLAYING = os.path.join(gettempdir(), "catt_playing")
 DEFAULT_MPV_SOCKET = os.path.join(gettempdir(), "mpv_socket")
@@ -29,7 +36,9 @@ REGEX_REDDITOR = re.compile(
         ]
     )
 )
-NOW = int(datetime.now().timestamp())
+REGEX_V_REDD_IT = re.compile("https?://v.redd.it/(?:[^/?#&]+)")
+APPLICATION_START = now()
+YT_IES = yt_dlp.extractor.gen_extractors()
 
 try:
     TERMINAL_SIZE = os.get_terminal_size()
